# Matrix Library

Questa libreria Python permette di eseguire calcoli matriciali usando il modulo CFFI per integrare codice C.

## Funzionalità
- Moltiplicazione di matrici
- Trasposizione di matrici
- Somma di matrici